#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-splice-plugin-2.3.0.0-HDB4zUEyGbw2qZS5Y5H0TO
key:                  hls-splice-plugin-2.3.0.0-HDB4zUEyGbw2qZS5Y5H0TO
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  cfef9d0a1e01ebd4e4ffecfe2e0d6d11
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.3.0.0-HDB4zUEyGbw2qZS5Y5H0TO
depends:
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o base-4.18.2.1 containers-0.6.7
    dlist-1.0-Eygr3YxXU3I4OAzq8xpe04 extra-1.7.16-92gEBqN3yIpF5We3DBC4D
    foldl-1.4.18-BBNInaHQ78L2JuF85AJif2 ghc-9.6.6
    ghc-exactprint-1.7.1.0-GibOHdaOmEHKz6gt8mkn0G
    ghcide-2.3.0.0-hSJ45aUJouJ5cajib6Y2r
    hls-plugin-api-2.3.0.0-HIrFfwLMl6A3cQVZo1Nuqf
    hls-refactor-plugin-2.3.0.0-1qLuSrG2gTvGUqbZaUcRik
    lens-5.3.5-60ILU9p4A3b30ZI7X5UwGa
    lsp-2.2.0.0-8keiVbyHMomIz2bmB3Jsqn mtl-2.3.1
    retrie-1.2.3-GKv6R4WMZqC7Ff3DSN62BK
    syb-0.7.3-IWvKvWWONKwAx7053zcTAl text-2.0.2 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

